#!/bin/bash
#SBATCH --job-name=val-eval
#SBATCH --output=/tmp/val-eval_%A.out
#SBATCH --error=/tmp/val-eval_%A.err
#SBATCH --time=48:00:00
#SBATCH --partition=v100,gpu
#SBATCH --mem=100G
#SBATCH --cpus-per-task=10
#SBATCH --gres=gpu:2
#SBATCH --exclude=gpu-1,gpu-2


source ../remote/base.sh

# CLI arguments
PATH_TO_CKPT=$1
MODEL_NAME=$2
BATCH_SIZE=$3

# 1. Generate patient representations
echo "Command run: '$0 $@'" | tee /dev/stderr
python3 ../../eval/ehrshot.py \
    --path_to_database /path/to/database \
    --path_to_labels_dir /path/to/labels \
    --path_to_features_dir /path/to/features \
    --path_to_tokenized_timelines_dir /path/to/tokenized_timelines \
    --path_to_model $PATH_TO_CKPT \
    --model_name $MODEL_NAME \
    --batch_size $BATCH_SIZE \
    --embed_strat last \
    --chunk_strat last \
    --device $DEVICE

if [ $? -ne 0 ]; then
    echo "Error: Failed to generate patient representations"
    exit 1
fi

# 2. Evaluate patient representations
CKPT=$(basename "$PATH_TO_CKPT")
CKPT="${CKPT%.*}"
cd /apth/to/ehrshot/scripts
bash 7_eval.sh "${MODEL_NAME}_${CKPT}_chunk:last_embed:last" --mimic4 --is_use_slurm
