#!/bin/bash
#SBATCH --job-name=val-eval
#SBATCH --output=/tmp/val-eval_%A.out
#SBATCH --error=/tmp/val-eval_%A.err
#SBATCH --time=48:00:00
#SBATCH --partition=v100,gpu
#SBATCH --mem=100G
#SBATCH --cpus-per-task=10
#SBATCH --gres=gpu:2
#SBATCH --exclude=gpu-1,gpu-2

child_pids=()
stop_child_processes() {
    for pid in "${child_pids[@]}"; do
        pkill -P "$pid"
        kill "$pid"
    done
}

trap 'stop_child_processes' SIGTERM SIGINT

cd ../remote
source base.sh
cd ../../eval/

RUN_ARGS=(
    "/path/to/hf_ehr/cache/runs_backup/mamba-tiny-8192--clmbr/ckpts/train-tokens-total_nonPAD-ckpt_val=2000000000-persist.ckpt"
    "/path/to/hf_ehr/cache/runs_backup/mamba-tiny-16384--clmbr/ckpts/train-tokens-total_nonPAD-ckpt_val=2000000000-persist.ckpt"
)

# Loop over the RUN_NAMES and args
for i in "${!RUN_NAMES[@]}"; do
    RUN_NAME="${i}"
    RUN_ARG=${RUN_ARGS[i]}
    STDOUT=/path/to/${RUN_NAME}_ppl_${SLURM_JOB_ID}.out
    STDERR=/path/to/${RUN_NAME}_ppl_${SLURM_JOB_ID}.err
    echo "Launching job #${i} for '${RUN_NAME}' with args '${RUN_ARG}' with slurm job id '${SLURM_JOB_ID}'"
    
    EXTRA="--split val --device cuda:${i}"

    # Run command
    python3 val_ppl.py --path_to_ckpt_dir $RUN_ARG $EXTRA > $STDOUT 2> $STDERR &

    child_pids+=($!)
done

wait