#!/bin/bash

source config.sh

source /share/sw/open/anaconda/3.10.2/etc/profile.d/conda.sh

ENV_NAME="hf_env"
REQUIREMENTS="../../../requirements.txt"

if [[ "$SLURM_JOB_PARTITION" == "h100" ]]; then
    echo "Detected H100 Partition"
    if [[ ! -e "/local-scratch/users/hf_ehr/$ENV_NAME" ]]; then
        conda create --prefix=/local-scratch/users/hf_ehr/$ENV_NAME python=3.10 -y # one-time setup
    fi
    conda activate /home/${ENV_NAME}
elif [[ "$SLURM_JOB_PARTITION" == "a100" ]]; then
    echo "Detected A100 Partition"
    if [[ ! -e "/local-scratch/hf_ehr/$ENV_NAME" ]]; then
        conda create --prefix=/local-scratch/hf_ehr/$ENV_NAME python=3.10 -y # one-time setup
    fi
    conda activate /local-scratch/hf_ehr/$ENV_NAME
elif [[ "$SLURM_JOB_PARTITION" == "v100" ]]; then
    echo "Detected V100 Partition"
    if [[ ! -e "/local-scratch/hf_ehr/$ENV_NAME" ]]; then
        conda create --prefix=/local-scratch/hf_ehr/$ENV_NAME python=3.10 -y # one-time setup
    fi
    conda activate /local-scratch/hf_ehr/$ENV_NAME
elif [[ "$SLURM_JOB_PARTITION" == "gpu" ]]; then
    echo "Detected GPU Partition"
    if [[ ! -e "/home/$USER/$ENV_NAME" ]]; then
        conda create --prefix=/home/$ENV_NAME python=3.10 -y # one-time setup
    fi
    conda activate /home/$USER/${ENV_NAME}
elif [[ "$SLURM_JOB_PARTITION" == "normal" ]]; then
    echo "Detected Normal Partition"
    if [[ ! -e "/home/$ENV_NAME" ]]; then
        conda create --prefix=/home/$ENV_NAME python=3.10 -y # one-time setup
    fi
    conda activate /home/${ENV_NAME}
else
    echo "Unknown SLURM partition: $SLURM_JOB_PARTITION"
    exit 1
fi

# Install hf_ehr + Python packages
python -m pip install -r $REQUIREMENTS
# python -m pip install -e ../../../

# Some a100 / h100 specific installs
if [[ "$SLURM_JOB_PARTITION" == "a100" ]] || [[ "$SLURM_JOB_PARTITION" == "h100" ]]; then
    python -m pip install mamba-ssm==2.2.2 causal-conv1d==1.4.0
fi